==> remark-lint-3.2.1.tgz: package/history.md <==
<!--remark setext-->

<!--lint disable no-multiple-toplevel-headings -->

3.2.1 / 2016-04-26
==================

*   Fix incorrect error in `no-heading-content-indent` ([`1f2e9a8`](https://github.com/wooorm/remark-lint/commit/1f2e9a8))
*   Fix CRLF line-endings in `hard-break-spaces` ([`31f5069`](https://github.com/wooorm/remark-lint/commit/31f5069))

3.2.0 / 2016-04-04
==================

*   Add support for global externals in Electron ([`2b31591`](https://github.com/wooorm/remark-lint/commit/2b31591))

3.1.0 / 2016-04-03
==================

*   Update main heading rules to accept preferred depth ([`7f4a51e`](https://github.com/wooorm/remark-lint/commit/7f4a51e))
*   Remove `:` requirement for `no-emphasis-as-heading` ([`d54441e`](https://github.com/wooorm/remark-lint/commit/d54441e))

3.0.0 / 2016-02-14
==================

*   Remove support for Duo ([`e55fb3a`](https://github.com/wooorm/remark-lint/commit/e55fb3a))
*   Update for changes in remark@4.0.0 ([`7fde792`](https://github.com/wooorm/remark-lint/commit/7fde792))
*   Add example for running remark with lint plugin ([`34d19b4`](https://github.com/wooorm/remark-lint/commit/34d19b4))

2.3.1 / 2016-02-03
==================

*   Fix Travis deploy to GitHub Releases ([`203367c`](https://github.com/wooorm/remark-lint/commit/203367c))

2.3.0 / 2016-02-03
==================

*   Update support for configuration comments ([`870cb99`](https://github.com/wooorm/remark-lint/commit/870cb99))
*   Fix literal URL and blank lines detection ([`b6309f0`](https://github.com/wooorm/remark-lint/commit/b6309f0))
*   Add `remark-lint-code` to list of external rules ([`a81e82b`](https://github.com/wooorm/remark-lint/commit/a81e82b))

2.2.1 / 2016-01-15
==================

*   Fix `list-item-indent` for non-incremented lists ([`e708a1c`](https://github.com/wooorm/remark-lint/commit/e708a1c))

2.2.0 / 2016-01-13
==================

*   Add support for global externals when running globally ([`589b4d7`](https://github.com/wooorm/remark-lint/commit/589b4d7))

2.1.0 / 2016-01-09
==================

*   Update `readme.md` to reflect `screenshot.png` ([`b2c4637`](https://github.com/wooorm/remark-lint/commit/b2c4637))
*   Rename `screen-shot.png` to `screenshot.png` ([`9c48497`](https://github.com/wooorm/remark-lint/commit/9c48497))
*   Update `screen-shot.png` ([`cf8ede7`](https://github.com/wooorm/remark-lint/commit/cf8ede7))
*   Add `no-undefined-references` rule ([`8f6e055`](https://github.com/wooorm/remark-lint/commit/8f6e055))
*   Fix typo ([`2c628f2`](https://github.com/wooorm/remark-lint/commit/2c628f2))
*   Add `no-unused-definitions` rule ([`bde77ab`](https://github.com/wooorm/remark-lint/commit/bde77ab))
*   Update browserify ([`43042ea`](https://github.com/wooorm/remark-lint/commit/43042ea))
*   Rename `sentence-newline` external rule to remark ([`7ff9b74`](https://github.com/wooorm/remark-lint/commit/7ff9b74))

2.0.3 / 2016-01-06
==================

*   Fix silent warnings for invalid options ([`aada8e8`](https://github.com/wooorm/remark-lint/commit/aada8e8))
*   Add list of external rules to `readme.md` ([`298b33a`](https://github.com/wooorm/remark-lint/commit/298b33a))

2.0.2 / 2015-12-27
==================

*   Fix hard-break-spaces in indented blocks ([`a427c59`](https://github.com/wooorm/remark-lint/commit/a427c59))

2.0.1 / 2015-12-26
==================

*   Remove distribution files from source ([`e012e19`](https://github.com/wooorm/remark-lint/commit/e012e19))
*   Remove support for bower ([`690e38b`](https://github.com/wooorm/remark-lint/commit/690e38b))
*   Refactor npm test target ([`de65cd7`](https://github.com/wooorm/remark-lint/commit/de65cd7))
*   Replace internal dependency of mdast > remark ([`26e07c9`](https://github.com/wooorm/remark-lint/commit/26e07c9))

2.0.0 / 2015-12-24
==================

*   Add temporary warning to `readme.md` ([`795877f`](https://github.com/wooorm/remark-lint/commit/795877f))
*   Rebuild distribution files ([`8b88d8a`](https://github.com/wooorm/remark-lint/commit/8b88d8a))
*   Update fixtures for changes in remark ([`237c12c`](https://github.com/wooorm/remark-lint/commit/237c12c))
*   Update `logo.svg` ([`e027168`](https://github.com/wooorm/remark-lint/commit/e027168))
*   Rename `mdast-github` > `remark-github` ([`811ce91`](https://github.com/wooorm/remark-lint/commit/811ce91))
*   Remove superfluous warnings after changes in mdast ([`63cdcab`](https://github.com/wooorm/remark-lint/commit/63cdcab))
*   Update dependencies for changes in mdast ([`4537271`](https://github.com/wooorm/remark-lint/commit/4537271))
*   Add list of related tools to `readme.md` ([`50f350b`](https://github.com/wooorm/remark-lint/commit/50f350b))
*   Refactor API docs ([`ad6df51`](https://github.com/wooorm/remark-lint/commit/ad6df51))

1.1.1 / 2015-09-12
==================

*   Add support for camel-case properties ([`35c4066`](https://github.com/wooorm/remark-lint/commit/35c4066))

1.1.0 / 2015-08-31
==================

*   Add en- and disabling multiple rules in one comment ([`29976d0`](https://github.com/wooorm/remark-lint/commit/29976d0))
*   Replace `vfile` patching of data with vfile-namespaces ([`c1136a1`](https://github.com/wooorm/remark-lint/commit/c1136a1))

1.0.0 / 2015-08-17
==================

*   Update dependencies ([`4936d35`](https://github.com/wooorm/remark-lint/commit/4936d35))

0.4.5 / 2015-08-08
==================

*   Fix typo in definition-case warning ([`490ac16`](https://github.com/wooorm/remark-lint/commit/490ac16))

0.4.4 / 2015-08-05
==================

*   Remove maximum-line-length warnings on definitions ([`1119ca8`](https://github.com/wooorm/remark-lint/commit/1119ca8))
*   Add `linter-markdown` to `readme.md` ([`7de8847`](https://github.com/wooorm/remark-lint/commit/7de8847))

0.4.3 / 2015-08-04
==================

*   Fix failure on block-quotes without children ([`a9aaff7`](https://github.com/wooorm/remark-lint/commit/a9aaff7))
*   Update mdast dev-dependency ([`34df79c`](https://github.com/wooorm/remark-lint/commit/34df79c))
*   Add vfile as a dev-dependency ([`84d1ce3`](https://github.com/wooorm/remark-lint/commit/84d1ce3))

0.4.2 / 2015-07-12
==================

*   Remove peer-dependencies ([`8d70fcf`](https://github.com/wooorm/remark-lint/commit/8d70fcf))

0.4.1 / 2015-07-05
==================

*   Remove component support ([`58d7e6b`](https://github.com/wooorm/remark-lint/commit/58d7e6b))
*   Refactor to externalise `lib/utilities/` ([`eb78529`](https://github.com/wooorm/remark-lint/commit/eb78529))

0.4.0 / 2015-06-29
==================

*   Add gap support ([`136e760`](https://github.com/wooorm/remark-lint/commit/136e760))
*   Update mdast ([`2d122e4`](https://github.com/wooorm/remark-lint/commit/2d122e4))

0.3.0 / 2015-06-20
==================

*   Add checkbox-content-indent rule ([`7b55519`](https://github.com/wooorm/remark-lint/commit/7b55519))
*   Fix dot-files from being read as fixtures ([`ecbec2c`](https://github.com/wooorm/remark-lint/commit/ecbec2c))
*   Add checkbox-character-style rule ([`7ed4579`](https://github.com/wooorm/remark-lint/commit/7ed4579))
*   Fix tests for invalid position given my mdast-range ([`55d1128`](https://github.com/wooorm/remark-lint/commit/55d1128))
*   Add missing jsdoc comment ([`63b83b9`](https://github.com/wooorm/remark-lint/commit/63b83b9))
*   Update eslint ([`a3b0829`](https://github.com/wooorm/remark-lint/commit/a3b0829))
*   Update mdast, mdast-yaml-config ([`52bac04`](https://github.com/wooorm/remark-lint/commit/52bac04))

0.2.0 / 2015-06-13
==================

*   Remove mdast-usage, add mdast-yaml-config as dependencies ([`053674f`](https://github.com/wooorm/remark-lint/commit/053674f))
*   Add images to blacklist for maximum-line-length ([`ba6d270`](https://github.com/wooorm/remark-lint/commit/ba6d270))
*   Refactor to use rawgit references to images in `readme.md` ([`3f6344c`](https://github.com/wooorm/remark-lint/commit/3f6344c))
*   Add support for external rules ([`5162a09`](https://github.com/wooorm/remark-lint/commit/5162a09))
*   Refactor additional, fileless, rules support ([`6d2ba65`](https://github.com/wooorm/remark-lint/commit/6d2ba65))
*   Adds support for automatic doc generation for file-less rules ([`29965a3`](https://github.com/wooorm/remark-lint/commit/29965a3))
*   Add `reset` docs to rule generation script ([`77b8bfd`](https://github.com/wooorm/remark-lint/commit/77b8bfd))
*   Adds `reset` rule to docs ([`90a5f8a`](https://github.com/wooorm/remark-lint/commit/90a5f8a))
*   Update wording re rules in `readme.md` ([`00d9ba4`](https://github.com/wooorm/remark-lint/commit/00d9ba4))
*   Update rule count in `readme.md` ([`f937cf4`](https://github.com/wooorm/remark-lint/commit/f937cf4))

0.1.0 / 2015-06-11
==================

==> remark-lint-4.0.0.tgz: package/history.md <==
<!--remark setext-->

<!--lint disable no-multiple-toplevel-headings -->

4.0.0 / 2016-06-06
==================

*   Add support for setting allowed file-name characters ([`fd908a4`](https://github.com/wooorm/remark-lint/commit/fd908a4))
*   Fix parameters when using reset ([`b8f52a9`](https://github.com/wooorm/remark-lint/commit/b8f52a9))
*   Update `list-item-spacing` message ([`d562d6e`](https://github.com/wooorm/remark-lint/commit/d562d6e))
*   Fix checkbox lists starting with links ([`019ff36`](https://github.com/wooorm/remark-lint/commit/019ff36))

3.2.1 / 2016-04-26
==================

*   Fix incorrect error in `no-heading-content-indent` ([`1f2e9a8`](https://github.com/wooorm/remark-lint/commit/1f2e9a8))
*   Fix CRLF line-endings in `hard-break-spaces` ([`31f5069`](https://github.com/wooorm/remark-lint/commit/31f5069))

3.2.0 / 2016-04-04
==================

*   Add support for global externals in Electron ([`2b31591`](https://github.com/wooorm/remark-lint/commit/2b31591))

3.1.0 / 2016-04-03
==================

*   Update main heading rules to accept preferred depth ([`7f4a51e`](https://github.com/wooorm/remark-lint/commit/7f4a51e))
*   Remove `:` requirement for `no-emphasis-as-heading` ([`d54441e`](https://github.com/wooorm/remark-lint/commit/d54441e))

3.0.0 / 2016-02-14
==================

*   Remove support for Duo ([`e55fb3a`](https://github.com/wooorm/remark-lint/commit/e55fb3a))
*   Update for changes in remark@4.0.0 ([`7fde792`](https://github.com/wooorm/remark-lint/commit/7fde792))
*   Add example for running remark with lint plugin ([`34d19b4`](https://github.com/wooorm/remark-lint/commit/34d19b4))

2.3.1 / 2016-02-03
==================

*   Fix Travis deploy to GitHub Releases ([`203367c`](https://github.com/wooorm/remark-lint/commit/203367c))

2.3.0 / 2016-02-03
==================

*   Update support for configuration comments ([`870cb99`](https://github.com/wooorm/remark-lint/commit/870cb99))
*   Fix literal URL and blank lines detection ([`b6309f0`](https://github.com/wooorm/remark-lint/commit/b6309f0))
*   Add `remark-lint-code` to list of external rules ([`a81e82b`](https://github.com/wooorm/remark-lint/commit/a81e82b))

2.2.1 / 2016-01-15
==================

*   Fix `list-item-indent` for non-incremented lists ([`e708a1c`](https://github.com/wooorm/remark-lint/commit/e708a1c))

2.2.0 / 2016-01-13
==================

*   Add support for global externals when running globally ([`589b4d7`](https://github.com/wooorm/remark-lint/commit/589b4d7))

2.1.0 / 2016-01-09
==================

*   Update `readme.md` to reflect `screenshot.png` ([`b2c4637`](https://github.com/wooorm/remark-lint/commit/b2c4637))
*   Rename `screen-shot.png` to `screenshot.png` ([`9c48497`](https://github.com/wooorm/remark-lint/commit/9c48497))
*   Update `screen-shot.png` ([`cf8ede7`](https://github.com/wooorm/remark-lint/commit/cf8ede7))
*   Add `no-undefined-references` rule ([`8f6e055`](https://github.com/wooorm/remark-lint/commit/8f6e055))
*   Fix typo ([`2c628f2`](https://github.com/wooorm/remark-lint/commit/2c628f2))
*   Add `no-unused-definitions` rule ([`bde77ab`](https://github.com/wooorm/remark-lint/commit/bde77ab))
*   Update browserify ([`43042ea`](https://github.com/wooorm/remark-lint/commit/43042ea))
*   Rename `sentence-newline` external rule to remark ([`7ff9b74`](https://github.com/wooorm/remark-lint/commit/7ff9b74))

2.0.3 / 2016-01-06
==================

*   Fix silent warnings for invalid options ([`aada8e8`](https://github.com/wooorm/remark-lint/commit/aada8e8))
*   Add list of external rules to `readme.md` ([`298b33a`](https://github.com/wooorm/remark-lint/commit/298b33a))

2.0.2 / 2015-12-27
==================

*   Fix hard-break-spaces in indented blocks ([`a427c59`](https://github.com/wooorm/remark-lint/commit/a427c59))

2.0.1 / 2015-12-26
==================

*   Remove distribution files from source ([`e012e19`](https://github.com/wooorm/remark-lint/commit/e012e19))
*   Remove support for bower ([`690e38b`](https://github.com/wooorm/remark-lint/commit/690e38b))
*   Refactor npm test target ([`de65cd7`](https://github.com/wooorm/remark-lint/commit/de65cd7))
*   Replace internal dependency of mdast > remark ([`26e07c9`](https://github.com/wooorm/remark-lint/commit/26e07c9))

2.0.0 / 2015-12-24
==================

*   Add temporary warning to `readme.md` ([`795877f`](https://github.com/wooorm/remark-lint/commit/795877f))
*   Rebuild distribution files ([`8b88d8a`](https://github.com/wooorm/remark-lint/commit/8b88d8a))
*   Update fixtures for changes in remark ([`237c12c`](https://github.com/wooorm/remark-lint/commit/237c12c))
*   Update `logo.svg` ([`e027168`](https://github.com/wooorm/remark-lint/commit/e027168))
*   Rename `mdast-github` > `remark-github` ([`811ce91`](https://github.com/wooorm/remark-lint/commit/811ce91))
*   Remove superfluous warnings after changes in mdast ([`63cdcab`](https://github.com/wooorm/remark-lint/commit/63cdcab))
*   Update dependencies for changes in mdast ([`4537271`](https://github.com/wooorm/remark-lint/commit/4537271))
*   Add list of related tools to `readme.md` ([`50f350b`](https://github.com/wooorm/remark-lint/commit/50f350b))
*   Refactor API docs ([`ad6df51`](https://github.com/wooorm/remark-lint/commit/ad6df51))

1.1.1 / 2015-09-12
==================

*   Add support for camel-case properties ([`35c4066`](https://github.com/wooorm/remark-lint/commit/35c4066))

1.1.0 / 2015-08-31
==================

*   Add en- and disabling multiple rules in one comment ([`29976d0`](https://github.com/wooorm/remark-lint/commit/29976d0))
*   Replace `vfile` patching of data with vfile-namespaces ([`c1136a1`](https://github.com/wooorm/remark-lint/commit/c1136a1))

1.0.0 / 2015-08-17
==================

*   Update dependencies ([`4936d35`](https://github.com/wooorm/remark-lint/commit/4936d35))

0.4.5 / 2015-08-08
==================

*   Fix typo in definition-case warning ([`490ac16`](https://github.com/wooorm/remark-lint/commit/490ac16))

0.4.4 / 2015-08-05
==================

*   Remove maximum-line-length warnings on definitions ([`1119ca8`](https://github.com/wooorm/remark-lint/commit/1119ca8))
*   Add `linter-markdown` to `readme.md` ([`7de8847`](https://github.com/wooorm/remark-lint/commit/7de8847))

0.4.3 / 2015-08-04
==================

*   Fix block-quotes without children ([`a9aaff7`](https://github.com/wooorm/remark-lint/commit/a9aaff7))
*   Update mdast dev-dependency ([`34df79c`](https://github.com/wooorm/remark-lint/commit/34df79c))
*   Add vfile as a dev-dependency ([`84d1ce3`](https://github.com/wooorm/remark-lint/commit/84d1ce3))

0.4.2 / 2015-07-12
==================

*   Remove peer-dependencies ([`8d70fcf`](https://github.com/wooorm/remark-lint/commit/8d70fcf))

0.4.1 / 2015-07-05
==================

*   Remove component support ([`58d7e6b`](https://github.com/wooorm/remark-lint/commit/58d7e6b))
*   Refactor to externalise `lib/utilities/` ([`eb78529`](https://github.com/wooorm/remark-lint/commit/eb78529))

0.4.0 / 2015-06-29
==================

*   Add gap support ([`136e760`](https://github.com/wooorm/remark-lint/commit/136e760))
*   Update mdast ([`2d122e4`](https://github.com/wooorm/remark-lint/commit/2d122e4))

0.3.0 / 2015-06-20
==================

*   Add checkbox-content-indent rule ([`7b55519`](https://github.com/wooorm/remark-lint/commit/7b55519))
*   Fix dot-files from being read as fixtures ([`ecbec2c`](https://github.com/wooorm/remark-lint/commit/ecbec2c))
*   Add checkbox-character-style rule ([`7ed4579`](https://github.com/wooorm/remark-lint/commit/7ed4579))
*   Fix tests for invalid position given my mdast-range ([`55d1128`](https://github.com/wooorm/remark-lint/commit/55d1128))
*   Add missing jsdoc comment ([`63b83b9`](https://github.com/wooorm/remark-lint/commit/63b83b9))
*   Update eslint ([`a3b0829`](https://github.com/wooorm/remark-lint/commit/a3b0829))
*   Update mdast, mdast-yaml-config ([`52bac04`](https://github.com/wooorm/remark-lint/commit/52bac04))

0.2.0 / 2015-06-13
==================

*   Remove mdast-usage, add mdast-yaml-config as dependencies ([`053674f`](https://github.com/wooorm/remark-lint/commit/053674f))
*   Add images to blacklist for maximum-line-length ([`ba6d270`](https://github.com/wooorm/remark-lint/commit/ba6d270))
*   Refactor to use rawgit references to images in `readme.md` ([`3f6344c`](https://github.com/wooorm/remark-lint/commit/3f6344c))
*   Add support for external rules ([`5162a09`](https://github.com/wooorm/remark-lint/commit/5162a09))
*   Refactor additional, fileless, rules support ([`6d2ba65`](https://github.com/wooorm/remark-lint/commit/6d2ba65))
*   Adds support for automatic doc generation for file-less rules ([`29965a3`](https://github.com/wooorm/remark-lint/commit/29965a3))
*   Add `reset` docs to rule generation script ([`77b8bfd`](https://github.com/wooorm/remark-lint/commit/77b8bfd))
*   Adds `reset` rule to docs ([`90a5f8a`](https://github.com/wooorm/remark-lint/commit/90a5f8a))
*   Update wording re rules in `readme.md` ([`00d9ba4`](https://github.com/wooorm/remark-lint/commit/00d9ba4))
*   Update rule count in `readme.md` ([`f937cf4`](https://github.com/wooorm/remark-lint/commit/f937cf4))

0.1.0 / 2015-06-11
==================
